@@ -3,12 +3,11 @@ import os
 import sys
 import pytz
 import psycopg2
-
-import logging
+import fk.db.DatabaseConnection
 from flask import g
 
-from fk.db.DatabaseConnection import DatabaseConnection
 
+import logging
 
 logger = logging.getLogger(__name__)
 
@@ -16,7 +15,7 @@ logger = logging.getLogger(__name__)
 class Database:
     def __init__(self, config):
         self.config = config
-        self.dbc = DatabaseConnection.get_connection(self.config)
+        self.dbc = fk.db.DatabaseConnection.DatabaseConnection.get_connection(self.config)
         assert self.dbc.is_ok()
         self.create_tables()
 
